@@ -309,6 +309,9 @@ int main(
             degree = C->length;
          initializeStorageManager( degree);
          break;
+      case INVALID_OBJECT:
+         ERROR("main (cjrndper command)", "invalid object")
+         break;
    }
 
    /* Initialize random number generator. */
@@ -529,6 +532,9 @@ int main(
          strcpy( CConjugated->name, outputObjectName);
          writeCode( outputFileName, outputLibraryName, CConjugated, comment);
          break;
+      case INVALID_OBJECT:
+         ERROR("main (cjrndper command)", "invalid object")
+         break;
    }
 
    /* Write out the conjugating permutation, if requested, and close its file. */
